@@ -6,7 +6,7 @@ from .util import convert_size_to_bytes
 
 
 def main():
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     parser.add_argument("input")
     parser.add_argument("-o", "--output", help="Output file")
     parser.add_argument(
